@@ -4,18 +4,18 @@
 modname = "elasticsearch"
 distname = "cubicweb-elasticsearch"
 
-numversion = (0, 14, 0)
+numversion = (1, 1, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
 author = "LOGILAB S.A. (Paris, FRANCE)"
 author_email = "contact@logilab.fr"
 description = "Simple ElasticSearch indexing integration for CubicWeb"
-web = "https://forge.extranet.logilab.fr/cubicweb/cubes/%s" % distname
+web = f"https://forge.extranet.logilab.fr/cubicweb/cubes/{distname}"
 
 __depends__ = {
-    "cubicweb": ">= 3.38.0, < 3.39.0",
-    "six": ">= 1.4.0",
+    "cubicweb": ">= 4.0.0, < 5.0.0",
+    "cubicweb-web": ">= 1.0.0, < 2.0.0",
     "cwtags": None,
     "elasticsearch": ">=7.0.0,<8.0.0",
     "elasticsearch-dsl": ">=7.0.0,<8.0.0",
