@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
 """cubicweb-ctl plugin providing the index-in-es command
 
 :organization: Logilab
 :copyright: 2016-2017 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
-from __future__ import print_function
 
 import os.path as osp
 
@@ -111,7 +109,7 @@ class IndexInES(Command):
             es = indexer.get_connection()
             indexer.create_index()
             if self.config.index_name:
-                cnx.info("create ES index {}".format(self.config.index_name))
+                cnx.info(f"create ES index {self.config.index_name}")
                 indexer.create_index(index_name=self.config.index_name)
             if es:
                 if self.config.etypes:
@@ -122,7 +120,7 @@ class IndexInES(Command):
                     )
                     assert self.config.except_etypes not in etypes
                 if not self.config.etypes:
-                    cnx.debug("found indexable types: {}".format(",".join(etypes)))
+                    cnx.debug(f"found indexable types: {','.join(etypes)}")
                 for _ in parallel_bulk(
                     es,
                     self.bulk_actions(
@@ -168,7 +166,7 @@ class IndexInES(Command):
                     }
                     self.customize_data(data)
                     yield data
-            cnx.info("[{}] indexed {} {} entities".format(index_name, idx, etype))
+            cnx.info(f"[{index_name}] indexed {idx} {etype} entities")
 
     def customize_data(self, data):
         pass
