@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2023 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -64,7 +63,7 @@ def fulltext_indexable_rql(etype, cnx, eid=None):
     """
     varmaker = rqlvar_maker()
     V = next(varmaker)
-    rql = ["WHERE %s is %s" % (V, etype)]
+    rql = [f"WHERE {V} is {etype}"]
     if eid:
         rql.append("%s eid %i" % (V, eid))
     var = next(varmaker)
@@ -74,9 +73,9 @@ def fulltext_indexable_rql(etype, cnx, eid=None):
         "IFullTextIndexSerializable"
     ).fulltext_indexable_attributes:
         var = next(varmaker)
-        rql.append("%s %s %s" % (V, attr, var))
+        rql.append(f"{V} {attr} {var}")
         selected.append(var)
-    return "Any %s,%s %s" % (V, ",".join(selected), ",".join(rql))
+    return f"Any {V},{','.join(selected)} {','.join(rql)}"
 
 
 def indexable_entities(cnx, etype, chunksize=100000):
@@ -109,7 +108,7 @@ def indexable_entities(cnx, etype, chunksize=100000):
         rqlst.add_constant_restriction(mainvar, "eid", last_eid, "Int", ">")
         rql = rqlst.as_string()
         rqlst.recover()
-        cnx.debug("RQL: {}".format(rql))
+        cnx.debug(f"RQL: {rql}")
         rset = cnx.execute(rql)
         if not rset:
             break
@@ -144,7 +143,7 @@ def create_index(es, index_name, settings=None):
         log.debug("Failed to index in hook, could not connect to ES")
 
 
-def get_connection(config):
+def get_connection(config, timeout=None):
     """
     Get connection with config object, creates a persistent connexion and
     """
@@ -158,7 +157,7 @@ def get_connection(config):
                 hosts=locations.split(","),
                 verify_certs=config["elasticsearch-verify-certs"],
                 ssl_show_warn=config["elasticsearch-ssl-show-warn"],
-                timeout=20,
+                timeout=timeout or config["elasticsearch-timeout"],
             )
+            # test connection is alive while using the fonction
             return es
-        # TODO else ? raise KeyError - return None is OK?
