@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2023 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -41,7 +40,8 @@ def is_simple_query_string(query):
     ~N after a word signifies edit distance (fuzziness)
     ~N after a phrase signifies slop amount
 
-    https://www.elastic.co/guide/en/elasticsearch/reference/7.9/query-dsl-simple-query-string-query.html"""  # noqa
+    https://www.elastic.co/guide/en/elasticsearch/reference/7.9/query-dsl-simple-query-string-query.html
+    """  # noqa
     # for all operators except "-", if it appears, then we assume it is a simple query
     for operator in SIMPLE_QUERY_OPERATORS.replace("-", ""):
         if operator in query:
