@@ -30,17 +30,17 @@ class PersonFTIAdapter(IFullTextIndexSerializable):
         return self.entity.age
 
 
-class RealESTestMixin(object):
+class RealESTestMixin:
     @classmethod
     def setUpClass(cls):
         try:
             HTTPConnection("localhost:9200").request("GET", "/")
         except:  # noqa
             raise unittest.SkipTest("No ElasticSearch on localhost, skipping test")
-        super(RealESTestMixin, cls).setUpClass()
+        super().setUpClass()
 
     def setup_database(self):
-        super(RealESTestMixin, self).setup_database()
+        super().setup_database()
         self.config.global_set_option(
             "elasticsearch-locations", "http://localhost:9200"
         )
@@ -58,4 +58,4 @@ class RealESTestMixin(object):
                 connections.remove_connection("default")
             except KeyError:
                 pass
-            super(RealESTestMixin, self).tearDown()
+            super().tearDown()
