@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2023 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -65,7 +64,7 @@ class CWFacetedSearch(FacetedSearch):
         index=None,
         form=None,
         track_total_hits=True,
-        **kwargs
+        **kwargs,
     ):
         if index:
             self.index = index
@@ -82,11 +81,11 @@ class CWFacetedSearch(FacetedSearch):
         # Count all the hits by default
         self.track_total_hits = track_total_hits
         self.extra_kwargs = kwargs
-        super(CWFacetedSearch, self).__init__(query, filters, sort=sort)
+        super().__init__(query, filters, sort=sort)
 
     def search(self):
         # override methods to add custom pieces
-        s = super(CWFacetedSearch, self).search()
+        s = super().search()
         return s.extra(track_total_hits=self.track_total_hits)
 
     def query(self, search, query):
@@ -177,11 +176,11 @@ class ElasticSearchView(StartupView):
         # TODO if no ES configuration, redirect or display warning
         self.render_search_comp()
         query_string = self._cw.form.get("q", self._cw.form.get("search", ""))
-        self.w("<h1>%s</h1>" % self._cw._(self.title))
+        self.w(f"<h1>{self._cw._(self.title)}</h1>")
         response = self.do_search(query_string)
         if response.hits.total.value:
-            self.w("<h2>Resultats pour : <em>%s</em></h2>" % xml_escape(query_string))
-            self.w("Resultats: %s" % response.hits.total.value)
+            self.w(f"<h2>Resultats pour : <em>{xml_escape(query_string)}</em></h2>")
+            self.w(f"Resultats: {response.hits.total.value}")
             if hasattr(response, "facets"):
                 self.display_facets(response)
         self.display_results(response)
@@ -205,7 +204,7 @@ class ElasticSearchView(StartupView):
             index=self._cw.vreg.config.get("index-name"),
             doc_types=["_doc"],
             form=self._cw.form,
-            **kwargs
+            **kwargs,
         )[start:stop]
 
     def display_results(self, response):
@@ -227,14 +226,16 @@ class ElasticSearchView(StartupView):
             )
             self.customize_infos(infos)
             try:
-                self.w('<a href="%(url)s">%(title)s</a> (%(_score).2f)<br/>' % (infos))
+                self.w(
+                    f"<a href=\"{infos['url']}\">{infos['title']}</a> ({infos['_score']:.2f})<br/>"
+                )
                 if self._cw.form.get("debug-es"):
-                    self.w(" [%(keys)s] <br/>" % infos)
+                    self.w(f" [{infos['keys']}] <br/>")
             except KeyError:
-                self.w("Missing key in : %s" % infos.keys())
+                self.w(f"Missing key in : {infos.keys()}")
             try:
                 for fragment in result.meta.highlight.content:
-                    self.w("... %s" % BeautifulSoup(fragment, "lxml").get_text())
+                    self.w(f"... {BeautifulSoup(fragment, 'lxml').get_text()}")
                     self.w(" ... <br/>")
             except AttributeError:
                 pass
@@ -352,8 +353,8 @@ class ElasticSearchView(StartupView):
             if "page" in url_params:
                 del url_params["page"]
             self.w('<div class="facetBody vocabularyFacet">')
-            self.w('<div class="facetTitle">{}</div>'.format(attribute))
-            for (tag, count, selected) in response.facets[attribute]:
+            self.w(f'<div class="facetTitle">{attribute}</div>')
+            for tag, count, selected in response.facets[attribute]:
                 # facetValueSelected / facetValueDisabled in class
                 facet_item = (
                     '<div class="facetValue facetCheckBox">'
@@ -362,14 +363,12 @@ class ElasticSearchView(StartupView):
                     "    </span>"
                     "</div>"
                 )
-                if url_params.get("es_{}".format(attribute)) != tag:
-                    url_params["es_{}".format(attribute)] = str(tag)
+                if url_params.get(f"es_{attribute}") != tag:
+                    url_params[f"es_{attribute}"] = str(tag)
                 else:
-                    del url_params["es_{}".format(attribute)]
+                    del url_params[f"es_{attribute}"]
                 url = self._cw.build_url(**url_params)
-                content = (
-                    selected and '<div class="facet-active">{}</div>'.format(tag) or tag
-                )
+                content = selected and f'<div class="facet-active">{tag}</div>' or tag
                 self.w(facet_item.format(url, content, count))
             self.w("</div>")
         self.w("</div></aside>")
