@@ -1,15 +1,13 @@
-from __future__ import print_function
-
 import sys
 import unittest
 from io import StringIO
 
-from mock import patch
+from unittest.mock import patch
 
 from elasticsearch_dsl.faceted_search import FacetedResponse
 from elasticsearch_dsl.search import Search
 
-from cubicweb.devtools import testlib
+from cubicweb_web.devtools import testlib
 from cubicweb.cwconfig import CubicWebConfiguration
 from cubicweb_elasticsearch import ccplugin
 from cubicweb_elasticsearch.es import indexable_types, fulltext_indexable_rql
@@ -19,17 +17,15 @@ from cubicweb_elasticsearch.es import indexable_types, fulltext_indexable_rql
 # so that the traces show the full stack, not just starting from connection.http_*
 class ExportElasticSearchTC(testlib.AutoPopulateTest):
     # ignore ComputedRelations
-    ignored_relations = set(
-        (
-            "narrower_concept",
-            "hidden_label",
-            "preferred_label",
-            "alternative_label",
-        )
-    )
+    ignored_relations = {
+        "narrower_concept",
+        "hidden_label",
+        "preferred_label",
+        "alternative_label",
+    }
 
     def setup_database(self):
-        super(ExportElasticSearchTC, self).setup_database()
+        super().setup_database()
         self.orig_config_for = CubicWebConfiguration.config_for
         config_for = lambda appid, *args, **kwargs: self.config  # noqa
         CubicWebConfiguration.config_for = staticmethod(config_for)
@@ -46,7 +42,7 @@ class ExportElasticSearchTC(testlib.AutoPopulateTest):
 
     def tearDown(self):
         CubicWebConfiguration.config_for = self.orig_config_for
-        super(ExportElasticSearchTC, self).tearDown()
+        super().tearDown()
 
     def test_indexable_types(self):
         with self.admin_access.repo_cnx() as cnx:
@@ -83,9 +79,7 @@ class ExportElasticSearchTC(testlib.AutoPopulateTest):
         finally:
             sys.stdout = sys.__stdout__
         with self.admin_access.repo_cnx() as cnx:
-            self.assertTrue(
-                cnx.execute("Any X WHERE X is %(etype)s" % {"etype": self.tested_etype})
-            )
+            self.assertTrue(cnx.execute(f"Any X WHERE X is {self.tested_etype}"))
         # TODO - put this somewhere where it tests on the first get_connection
         # create.assert_called_with(ignore=400,
         #                          index='unittest_index_name',
@@ -131,7 +125,7 @@ def mock_execute(count):
     def _result(i):
         return {
             "_source": {
-                "cwuri": "http://example.org/{}".format(i),
+                "cwuri": f"http://example.org/{i}",
                 "eid": i,
                 "cw_etype": "Person",
                 "name": "Jean Valjean",
@@ -156,8 +150,7 @@ def mock_cnx(*args, **kwargs):
     return True
 
 
-class ElasticSearchViewsTC(testlib.CubicWebTC):
-
+class ElasticSearchViewsTC(testlib.WebCWTC):
     # TODO generate X tests ranging the number of results from 1 to 150
     @patch("elasticsearch_dsl.search.Search.execute", new=mock_execute_1)
     @patch("elasticsearch_dsl.connections.connections.get_connection", new=mock_cnx)
@@ -181,7 +174,7 @@ class ElasticSearchViewsTC(testlib.CubicWebTC):
             self.view("esearch", req=req, template=None)
 
 
-class ElasticsearchTC(testlib.CubicWebTC):
+class ElasticsearchTC(testlib.WebCWTC):
     def test_1(self):
         with self.admin_access.cnx() as cnx:
             etype = "Person"
