@@ -1,6 +1,6 @@
 import unittest
 
-from mock import patch
+from unittest.mock import patch
 
 from cubicweb.devtools import testlib
 from cubicweb.cwconfig import CubicWebConfiguration
@@ -8,7 +8,7 @@ from cubicweb.cwconfig import CubicWebConfiguration
 
 class IndexHookTC(testlib.CubicWebTC):
     def setup_database(self):
-        super(IndexHookTC, self).setup_database()
+        super().setup_database()
         self.orig_config_for = CubicWebConfiguration.config_for
 
         def config_for(appid):
