@@ -1,6 +1,6 @@
 import unittest
 
-from mock import patch
+from unittest.mock import patch
 
 from cubicweb.devtools import testlib
 from cubicweb.cwconfig import CubicWebConfiguration
@@ -14,7 +14,7 @@ from cubicweb_elasticsearch.testutils import (
 
 class IFullTextIndexSerializableTC(testlib.CubicWebTC):
     def setup_database(self):
-        super(IFullTextIndexSerializableTC, self).setup_database()
+        super().setup_database()
         self.orig_config_for = CubicWebConfiguration.config_for
 
         def config_for(appid):
@@ -64,7 +64,7 @@ class IFullTextIndexSerializableTC(testlib.CubicWebTC):
                     ("title", "program"),
                 ):
                     self.assertEqual(kwargs["body"][arg_name], expected_value)
-                self.assertFalse("content_format" in kwargs["body"])
+                self.assertNotIn("content_format", kwargs["body"])
                 # update BlogEntry
                 bentry.cw_set(title="Programme")
                 index.reset_mock()
@@ -82,7 +82,7 @@ class IFullTextIndexSerializableTC(testlib.CubicWebTC):
                     ("title", "Programme"),
                 ):
                     self.assertEqual(kwargs["body"][arg_name], expected_value)
-                self.assertFalse("content_format" in kwargs["body"])
+                self.assertNotIn("content_format", kwargs["body"])
 
     @patch("elasticsearch.client.indices.IndicesClient.create")
     @patch("elasticsearch.client.indices.IndicesClient.exists")
