@@ -1,6 +1,6 @@
 import unittest
 
-from mock import patch
+from unittest.mock import patch
 
 from cubicweb.devtools.testlib import CubicWebTC
 
